@@ -1,5 +1,9 @@
+from petisco.domain.value_objects.client_id import ClientId
+from petisco.domain.value_objects.user_id import UserId
+
+
 class Token:
-    def __init__(self, client_id: str, user_id: str, token_type: str):
+    def __init__(self, client_id: ClientId, user_id: UserId, token_type: str):
         self.client_id = client_id
         self.user_id = user_id
         self.token_type = token_type
@@ -13,7 +17,9 @@ class Token:
     @staticmethod
     def from_token_payload(token_payload: dict):
         return Token(
-            client_id=token_payload.get("cli"),
-            user_id=token_payload.get("sub"),
+            client_id=ClientId(token_payload.get("cli")),
+            user_id=UserId(token_payload.get("sub"))
+            if token_payload.get("sub")
+            else None,
             token_type=token_payload.get("typ"),
         )
